# Rasdaman Installer Developer's Guide


## Directories overview

| *Directory*    | *Description*                                                  |
|:---------------|:---------------------------------------------------------------|
| profile        | Manages settings for configuring and installing rasdaman       |
| profiles       | A collection of sample profiles for testing, packaging, etc.   |
| validator      | Validate the system at a particular state                      |
| tpinstaller    | Install dependencies with support for different OS             |
| retriever      | Retrieve the sources of rasdaman or a patch to be applied      |
| builder        | Configure and build rasdaman                                   |
| preparer       | Prepares the environment for installing / running rasdaman     |
| finalizers     | Actions executed after system is installed and running         |
| tester         | Runs the rasdaman tests                                        |
| janitor        | Clean up the environment after the installer is executed       |
| packager       | Create and upload rasdaman packages (deb, rpm)                 |
| helper         | Python functions for utility cmd-line, logging, history        |
| strategies     | A strategy combines multiple components to install rasdaman    |


## Capabilities

The rasdaman installer can
* compile and install rasdaman, run the systemtest afterwards, insert demos
* uninstall rasdaman
* create RPM or Debian packages


## Workflow

The user fills in and specifies a **profile**, which determines how will rasdaman
be compiled and installed. Sample profiles are provided in the
`profiles/`` directory, for common configuration options for compiling from source,
and for creating RPM and Debian packages.

### main.py, profile

The installation profile is fed to **main.py** by the user. Alternatively there
are several convenience scripts like `install.sh`, `build_pkg_nightly.sh` and
`ci_test.sh`, which are simply wrappers around `main.py`.

In main.py, the provided profile is first parsed into a **Profile** object
(`profile/profile.py`), which provides convenient access to all options.

Further on, the Profile object is used to get a particular **Strategy**.
If the profile wants to build a package then a Strategy for installing or
updating packages is used, otherwise a general Strategy can handle all
other situations. The Strategy is executed; if systemtest error or other
exceptions happened, main.py returns with exit code 1, othewise it exits
successfully with code 0.

### strategies

A **Strategy** glues all parts together and allows to execute them with a single
_run()_ method call. The strategy execution performs:
* system validation
* dependency installation
* retrieving rasdaman (sources, packages, etc.)
* building rasdaman
* prepare the environment for running rasdaman
* finalizing the installation
* running tests
* packaging

A `Strategy` is generated by a **StrategyBuilder**, and there
are three such builders:
* `StrategyBuilder` for compiling/installing/running tests/generating
rasdaman package
* `PackageInstallStrategyBuilder`, used when _installing_ a rasdaman package


### validator

The **Validator**s perform various checks on the system before continuing
the installation.
* `RasdamanIsRunningValidator` checks if rasdaman is already running and tries
to stop it, exiting the installation if that fails.
* `RasdamanPackageValidator` removes deprecated-style RPM installation when
installing a package.


### tpinstaller

**OSInstaller** classes return the correct third-party dependencies across
various Linux distributions. Underneath **TPInstaller** classes are combined
to perform the actual installation, along with fixing permissions and
configuration details of the installed dependencies. At the end, after calling
`install()`, we should have a system setup with all packages, users and
credentials as needed for building and running rasdaman.

`DependenciesInstallerFactory` has a static method that returns the correct
`OSInstaller` for the current Linux distribution, or throws an error if the
distribution version is not supported.


### retriever

* `RepositoryRetriever` clones or pulls the rasdaman code.
* `PatchManagerRetriever` is used by jenkins to get and apply a specific patch.


### builder

**Builder** classes build a component (rasdaman, petascope, secore, etc.) by
running configure, make, make install.

* `RasdamanCmakeBuilder` runs cmake, make and make install. The configure
parameters come from the supplied `Configurer` object.


### preparer


### tester


### finalizer


### packager

The **Packager** packages the rasdaman installation in a specific format. There
are:
* `LinuxPackager` creates a Debian or RPM packages
  * specifically by the `DebPackager` or `RPMPackager`

The `LinuxPackager` performs several steps:
1. Fixes the absolute paths and other details to the values of the target system.
2. Copies the *rasdamaninstaller* itself into `/opt/rasdaman/share/rasdaman/installer/`.
3. It generates a couple of scripts in `/opt/rasdaman/share/rasdaman/installer/`:
  * `postinst.sh` executes the installer with the `profiles/package/install.toml`
  profile and starts rasdaman.
  * `preinst.sh` copies existing rasdaman config files from `/opt/rasdaman/etc`
  to the temporary packager location.
  * `postuninst.sh` remove some additional files because they were not part of the package itself, 
  but installed with the package pre-install script.
  * `preuninst.sh` stop rasdaman before uninstallation.
  * `postremove.sh` is executed after a package is erased
4. The package is finally generated with `fpm` (https://github.com/jordansissel/fpm)
