"""
 *
 * This file is part of rasdaman community.
 *
 * Rasdaman community is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Rasdaman community is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU  General Public License for more details.
 *
 * You should have received a copy of the GNU  General Public License
 * along with rasdaman community.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Copyright 2003 - 2016 Peter Baumann / rasdaman GmbH.
 *
 * For more information please see <http://www.rasdaman.org>
 * or contact Peter Baumann via <baumann@rasdaman.com>.
 *
"""
from __future__ import absolute_import
from .profile import Profile, ProfileException
import pytest


class TestProfile(object):
    def test_all_options(self):
        profile = Profile()
        profile.parse_profile("profiles/all_profile_options.toml")

    def test_invalid_bool(self):
        profile = Profile()
        with pytest.raises(ProfileException):
            profile.parse_profile("profile/testdata/test_invalid_bool.toml")

    def test_invalid_int(self):
        profile = Profile()
        with pytest.raises(ProfileException):
            profile.parse_profile("profile/testdata/test_invalid_int.toml")

    def test_invalid_alternative(self):
        profile = Profile()
        with pytest.raises(ProfileException):
            profile.parse_profile("profile/testdata/test_invalid_alternative.toml")

    def test_empty_value(self):
        profile = Profile()
        with pytest.raises(ProfileException):
            profile.parse_profile("profile/testdata/test_empty_value.toml")

    def test_invalid_value(self):
        profile = Profile()
        with pytest.raises(ProfileException):
            profile.parse_profile("profile/testdata/test_invalid_value.toml")

    def test_nonexisting_file(self):
        profile = Profile()
        with pytest.raises(IOError):
            profile.parse_profile("profile/testdata/test_nonexisting_file.toml")

    def test_default_values(self):
        profile = Profile()
        profile.parse_profile("profile/testdata/test_empty_file.toml")
        encoded = str(profile)
        expected = """
Install path: /opt/rasdaman/
User: rasdaman
Database: sqlite, /opt/rasdaman/data/
Repository: git://rasdaman.org/rasdaman.git
Version: master
Debug: False
Install webapps: True
  Petascopedb url: jdbc:postgresql://localhost:5432/petascopedb
  Petascopedb user: petauser
  Deployment: external
  Webapps path: None
  Webapps logs: None
Insert demos: True
Run systemtest: False
Generate package: False"""
        assert expected == encoded
