#!/bin/bash
# This script should be placed in the package_sources directory on the
# download server, and executed when newly built packages should be deployed
# to the www directory for download.

PROG=$(basename "$0")

hostname=$(hostname)
is_re=false
[ "$hostname" = "ras-download" ] && is_re=true

if ! $is_re; then
    WWWDIR="/data/www/download.rasdaman.org/packages"
    WWWDIR_NIGHTLY="$WWWDIR"
    SRCDIR="/home/download/package_sources"
    CREATEREPO=createrepo_c
else
    WWWDIR="/data/www/html/Download"
    WWWDIR_NIGHTLY="/data/www/DownloadInternal"
    SRCDIR="/data/package_source"
    CREATEREPO=createrepo
fi

log()  { echo "$PROG: $*"; }
error(){ echo "$PROG: $*" >&2; exit 1; }
usage()
{
    log "Usage: ./deploy_packages.sh [nightly|testing|stable]"
    exit 1
}

#
# There are multiple package releases per version, managed in a
# $WWWDIR/version_releases.txt file. The file has the following format:
#
# $pkg_type $os_version $pkg_version $current_release
# ...
# $pkg_type $os_version $pkg_version $current_release
#
# e.g.
#
# nightly jammy 10.0.0 4
#
# The release is read when building the package, e.g. in pkg_build_and_test.sh,
# and is updated (increased by 1) when the package is deployed, so that the
# next time a package with the same version is built, it will have the correct
# release number.
#
update_version_release()
{
    local os_version="$1"
    local pkg_version="$2"
    local version_releases
    version_releases="$WWWDIR/version_releases.txt"
    local next_release
    if grep -q "$pkg_type $os_version $pkg_version" "$version_releases"; then
        typeset -i current_release
        current_release=$(grep "$pkg_type $os_version $pkg_version" "$version_releases" | awk '{ print $4; }')
        next_release=$((current_release + 1))
        sed -i "s/$pkg_type $os_version $pkg_version $current_release/$pkg_type $os_version $pkg_version $next_release/" "$version_releases"
    else
        next_release=2
        echo "$pkg_type $os_version $pkg_version $next_release" >> "$version_releases"
    fi
    log "$pkg_type $os_version $pkg_version increased to release $next_release."
}

#
# deploy a DEB package into the repository and increase the release number
#
deploy_deb()
{
    local src_version="$1"
    local srcdir="${SRCDIR}/deb/$src_version/$pkg_type"
    local wwwdir="${WWWDIR}/deb/"

    echo
    echo
    log "Building $pkg_type $src_version repo..."
    if [ "$(find "$srcdir" -maxdepth 0 -empty | wc -l)" -ne 0 ]; then
       log "no packages found in the source directory $srcdir, skipping."
       return
    fi
    ls -l "$srcdir"

    local pkg
    for pkg in $(find "$srcdir" -name 'rasdaman*.deb'); do
      if [[ "$pkg_type" = nightly ]]; then
        # remove previous rasdaman packages
        reprepro -C "$pkg_type" -Vb "$wwwdir" remove "$src_version" rasdaman
      fi
      reprepro -C "$pkg_type" -Vb "$wwwdir" includedeb "$src_version" "$pkg" || \
          error "failed updating repository."
      if [[ "$pkg" == *rasdaman_[0-9]* ]]; then
        p=$(basename "$pkg")
        local pkg_version
        pkg_version=$(echo "$p" | sed 's/^rasdaman_//' | sed 's/'"$src_version"'.*//')
        update_version_release "$src_version" "$pkg_version"
      fi
    done

    rm -rfv "${srcdir:?}"/*
    log "$pkg_type $src_version repo updated."
}

#
# main
#

pkg_type="$1" # nightly|testing|stable
[[ "$pkg_type" == nightly || "$pkg_type" == stable || "$pkg_type" == testing ]] || usage
[[ "$pkg_type" == nightly ]] && WWWDIR="$WWWDIR_NIGHTLY"

#deploy_deb "bionic"
deploy_deb "focal"
deploy_deb "jammy"
deploy_deb "noble"

log "done."
