#!/bin/bash

SOURCE="${BASH_SOURCE[0]}"
while [ -h "$SOURCE" ] ; do SOURCE="$(readlink "$SOURCE")"; done
SCRIPT_DIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )"

readonly INSTALLER_SOURCE_PATH="$SCRIPT_DIR/../../"
readonly INSTALLER_VAGRANT_PATH="$SCRIPT_DIR/rasdamaninstaller"

usage()
{
    echo "Usage: run.sh (up|reload|ssh|sync|kill)"
    exit 0
}

sync_installer()
{
    rm -rf "$INSTALLER_VAGRANT_PATH"
    mkdir -p "$INSTALLER_VAGRANT_PATH"
    rsync -azq --exclude="/test/" "$INSTALLER_SOURCE_PATH"/* "$INSTALLER_VAGRANT_PATH"/ && echo "synced sources to $INSTALLER_VAGRANT_PATH successfully."
}

up()
{
    sync_installer
    vagrant up
}

reload()
{
    sync_installer
    vagrant reload --provision
}

login()
{
    vagrant ssh
}

destroy()
{
    vagrant destroy --force
}

if [ -n "$1" ]; then
    case "$1" in
        up) up;;
       ssh) login;;
      sync) sync_installer;;
    reload) reload;;
      kill) destroy;;
         *) usage;;
    esac
else
    usage
fi
